import React from "react";
import { render, screen, fireEvent } from "@testing-library/react";
import Button from "./Button";
describe("test Button component", function () {
    test("renders button with default text", function () {
        render(React.createElement(Button, { callback: function () { } }));
        var button = screen.getByRole("button", {
            name: /continue with facebook/i
        });
        expect(button).toBeInTheDocument();
    });
    test("renders button with custom width", function () {
        render(React.createElement(Button, { callback: function () { }, width: 200 }));
        var button = screen.getByRole("button");
        expect(button).toHaveStyle({ width: "200px" });
    });
    test("clicking button calls FB login API", function () {
        var mockLogin = jest.fn();
        var mockGetLoginStatus = jest.fn();
        window.FB = {
            login: mockLogin,
            api: jest.fn(),
            // @ts-ignore
            Event: {
                subscribe: jest.fn()
            },
            getLoginStatus: mockGetLoginStatus
        };
        render(React.createElement(Button, { callback: function () { }, scope: "email" }));
        var button = screen.getByRole("button");
        fireEvent.click(button);
        expect(mockLogin).toHaveBeenCalledWith(expect.any(Function), {
            scope: "email"
        });
    });
    test("clicking button calls callback with auth response", function () {
        var mockCallback = jest.fn();
        var mockLogin = jest.fn(function (callback) {
            return callback({ status: "connected", authResponse: { accessToken: "abc123" } });
        });
        var mockGetLoginStatus = jest.fn(function (callback) {
            return callback({ authResponse: { accessToken: "abc123" }, status: "connected" });
        });
        window.FB = {
            login: mockLogin,
            api: jest.fn(),
            // @ts-ignore
            Event: {
                subscribe: jest.fn()
            },
            getLoginStatus: mockGetLoginStatus
        };
        render(React.createElement(Button, { callback: mockCallback }));
        var button = screen.getByRole("button");
        fireEvent.click(button);
        expect(mockCallback).toHaveBeenCalledWith({ accessToken: "abc123" });
    });
});
//# sourceMappingURL=Button.test.js.map